@@ -171,9 +171,15 @@ class BaseAPI(object):
 
     def _request(self, http_method, stem, data={}, params={}):
         url = '%s/%s' % (self.url, stem)
+        data = json.dumps(data)
+        # getting rid of control characters
+        # that JSON will error out on
+        data = data.replace('\\r', ' ')
+        data = data.replace('\\t', ' ')
+        data = data.replace('\\n', ' ')
         kwargs = {
             'params': params,
-            'data': json.dumps(data),
+            'data': data,
             'headers': self.headers,
             'auth': (self.username, self.password),
             'proxies': self.proxies,
@@ -363,7 +369,7 @@ class Document(AvalaraBase):
     CANCEL_CODES = (CANCEL_POST_FAILED, CANCEL_DOC_DELETED, CANCEL_DOC_VOIDED, CANCEL_ADJUSTMENT_CANCELED)
 
 
-    _fields = ['DocType', 'DocId', 'DocCode', 'DocDate', 'CompanyCode', 'CustomerCode', 'Discount', 'Commit', 'CustomerUsageType', 'PurchaseOrderNo', 'ExemptionNo', 'PaymentDate', 'ReferenceCode']
+    _fields = ['DocType', 'DocId', 'DocCode', 'DocDate', 'CompanyCode', 'CustomerCode', 'Discount', 'Commit', 'CustomerUsageType', 'PurchaseOrderNo', 'ExemptionNo', 'PaymentDate', 'ReferenceCode', 'PosLaneCode', 'Client']
     _contains = ['Lines', 'Addresses']  # the automatic parsing in `def update` doesn't work here, but its never invoked here
     _has = ['DetailLevel', 'TaxOverride']
 
